pub struct Backends(/* private fields */);Expand description
Represents the backends that wgpu will use.
Implementations
Sourceimpl Backends
impl Backends
Sourcepub const VULKAN: Self
pub const VULKAN: Self
Backend::Vulkan.
Supported on Windows, Linux/Android, and macOS/iOS via Vulkan Portability (with the Vulkan feature enabled)
Sourcepub const GL: Self
pub const GL: Self
Backend::Gl.
Supported on Linux/Android, the web through webassembly via WebGL, and Windows and
macOS/iOS via ANGLE
Sourcepub const METAL: Self
pub const METAL: Self
Backend::Metal.
Supported on macOS and iOS.
Sourcepub const DX12: Self
pub const DX12: Self
Backend::Dx12.
Supported on Windows 10 and later
Sourcepub const BROWSER_WEBGPU: Self
pub const BROWSER_WEBGPU: Self
Backend::BrowserWebGpu.
Supported when targeting the web through WebAssembly with the webgpu feature enabled.
The WebGPU backend is special in several ways:
It is not not implemented by wgpu_core and instead by the higher level wgpu crate.
Whether WebGPU is targeted is decided upon the creation of the wgpu::Instance,
not upon adapter creation. See wgpu::Instance::new.
Sourceimpl Backends
impl Backends
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Backends
impl Backends
Sourcepub const fn iter(&self) -> Iter<Backends>
pub const fn iter(&self) -> Iter<Backends>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Backends>
pub const fn iter_names(&self) -> IterNames<Backends>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Backends
impl Backends
Sourcepub fn from_env() -> Option<Self>
pub fn from_env() -> Option<Self>
Gets a set of backends from the environment variable WGPU_BACKEND.
See Self::from_comma_list() for the format of the string.
Sourcepub fn with_env(&self) -> Self
pub fn with_env(&self) -> Self
Takes the given options, modifies them based on the WGPU_BACKEND environment variable, and returns the result.
Sourcepub fn from_comma_list(string: &str) -> Self
pub fn from_comma_list(string: &str) -> Self
Generates a set of backends from a comma separated list of case-insensitive backend names.
Whitespace is stripped, so both ‘gl, dx12’ and ‘gl,dx12’ are valid.
Always returns WEBGPU on wasm over webgpu.
Names:
- vulkan = “vulkan” or “vk”
- dx12 = “dx12” or “d3d12”
- metal = “metal” or “mtl”
- gles = “opengl” or “gles” or “gl”
- webgpu = “webgpu”